@@ -82,7 +82,7 @@ class AmiContextQuery():
 
 @jsii.data_type(jsii_type="monocdk-experiment.cloud_assembly_schema.ArtifactManifest", jsii_struct_bases=[], name_mapping={'type': 'type', 'dependencies': 'dependencies', 'environment': 'environment', 'metadata': 'metadata', 'properties': 'properties'})
 class ArtifactManifest():
-    def __init__(self, *, type: "ArtifactType", dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List["MetadataEntry"]]]=None, properties: typing.Optional[typing.Union["AwsCloudFormationStackProperties", "AssetManifestProperties", "TreeArtifactProperties"]]=None) -> None:
+    def __init__(self, *, type: "ArtifactType", dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List["MetadataEntry"]]]=None, properties: typing.Optional[typing.Union["AwsCloudFormationStackProperties", "AssetManifestProperties", "TreeArtifactProperties", "NestedCloudAssemblyProperties"]]=None) -> None:
         """A manifest for a single artifact within the cloud assembly.
 
         :param type: The type of artifact.
@@ -148,7 +148,7 @@ class ArtifactManifest():
         return self._values.get('metadata')
 
     @builtins.property
-    def properties(self) -> typing.Optional[typing.Union["AwsCloudFormationStackProperties", "AssetManifestProperties", "TreeArtifactProperties"]]:
+    def properties(self) -> typing.Optional[typing.Union["AwsCloudFormationStackProperties", "AssetManifestProperties", "TreeArtifactProperties", "NestedCloudAssemblyProperties"]]:
         """The set of properties for this artifact (depends on type).
 
         default
@@ -244,6 +244,12 @@ class ArtifactType(enum.Enum):
     stability
     :stability: experimental
     """
+    NESTED_CLOUD_ASSEMBLY = "NESTED_CLOUD_ASSEMBLY"
+    """Nested Cloud Assembly.
+
+    stability
+    :stability: experimental
+    """
 
 @jsii.data_type(jsii_type="monocdk-experiment.cloud_assembly_schema.AssemblyManifest", jsii_struct_bases=[], name_mapping={'version': 'version', 'artifacts': 'artifacts', 'missing': 'missing', 'runtime': 'runtime'})
 class AssemblyManifest():
@@ -1156,6 +1162,53 @@ class MissingContext():
         return 'MissingContext(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.data_type(jsii_type="monocdk-experiment.cloud_assembly_schema.NestedCloudAssemblyProperties", jsii_struct_bases=[], name_mapping={'directory_name': 'directoryName', 'display_name': 'displayName'})
+class NestedCloudAssemblyProperties():
+    def __init__(self, *, directory_name: str, display_name: typing.Optional[str]=None) -> None:
+        """Artifact properties for nested cloud assemblies.
+
+        :param directory_name: Relative path to the nested cloud assembly.
+        :param display_name: Display name for the cloud assembly. Default: - The artifact ID
+
+        stability
+        :stability: experimental
+        """
+        self._values = {
+            'directory_name': directory_name,
+        }
+        if display_name is not None: self._values["display_name"] = display_name
+
+    @builtins.property
+    def directory_name(self) -> str:
+        """Relative path to the nested cloud assembly.
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('directory_name')
+
+    @builtins.property
+    def display_name(self) -> typing.Optional[str]:
+        """Display name for the cloud assembly.
+
+        default
+        :default: - The artifact ID
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('display_name')
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return 'NestedCloudAssemblyProperties(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
 @jsii.data_type(jsii_type="monocdk-experiment.cloud_assembly_schema.RuntimeInfo", jsii_struct_bases=[], name_mapping={'libraries': 'libraries'})
 class RuntimeInfo():
     def __init__(self, *, libraries: typing.Mapping[str, str]) -> None:
@@ -1429,6 +1482,7 @@ __all__ = [
     "Manifest",
     "MetadataEntry",
     "MissingContext",
+    "NestedCloudAssemblyProperties",
     "RuntimeInfo",
     "SSMParameterContextQuery",
     "Tag",
