@@ -127,7 +127,7 @@ class CloudArtifact(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.cx_ap
     stability
     :stability: experimental
     """
-    def __init__(self, assembly: "CloudAssembly", id: str, *, type: _ArtifactType_9221e05d, dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]]=None, properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c]]=None) -> None:
+    def __init__(self, assembly: "CloudAssembly", id: str, *, type: _ArtifactType_9221e05d, dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]]=None, properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c, _NestedCloudAssemblyProperties_2d939e98]]=None) -> None:
         """
         :param assembly: -
         :param id: -
@@ -146,7 +146,7 @@ class CloudArtifact(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.cx_ap
 
     @jsii.member(jsii_name="fromManifest")
     @builtins.classmethod
-    def from_manifest(cls, assembly: "CloudAssembly", id: str, *, type: _ArtifactType_9221e05d, dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]]=None, properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c]]=None) -> typing.Optional["CloudArtifact"]:
+    def from_manifest(cls, assembly: "CloudAssembly", id: str, *, type: _ArtifactType_9221e05d, dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]]=None, properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c, _NestedCloudAssemblyProperties_2d939e98]]=None) -> typing.Optional["CloudArtifact"]:
         """Returns a subclass of ``CloudArtifact`` based on the artifact type defined in the artifact manifest.
 
         :param assembly: The cloud assembly from which to load the artifact.
@@ -245,6 +245,28 @@ class CloudAssembly(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.cx_ap
         """
         jsii.create(CloudAssembly, self, [directory])
 
+    @jsii.member(jsii_name="getNestedAssembly")
+    def get_nested_assembly(self, artifact_id: str) -> "CloudAssembly":
+        """Returns a nested assembly.
+
+        :param artifact_id: The artifact ID of the nested assembly.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "getNestedAssembly", [artifact_id])
+
+    @jsii.member(jsii_name="getNestedAssemblyArtifact")
+    def get_nested_assembly_artifact(self, artifact_id: str) -> "NestedCloudAssemblyArtifact":
+        """Returns a nested assembly artifact.
+
+        :param artifact_id: The artifact ID of the nested assembly.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "getNestedAssemblyArtifact", [artifact_id])
+
     @jsii.member(jsii_name="getStack")
     def get_stack(self, stack_name: str) -> "CloudFormationStackArtifact":
         """Returns a CloudFormation stack artifact by name from this assembly.
@@ -279,6 +301,8 @@ class CloudAssembly(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.cx_ap
     def get_stack_by_name(self, stack_name: str) -> "CloudFormationStackArtifact":
         """Returns a CloudFormation stack artifact from this assembly.
 
+        Will only search the current assembly.
+
         :param stack_name: the name of the CloudFormation stack.
 
         return
@@ -402,7 +426,7 @@ class CloudAssemblyBuilder(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experimen
         jsii.create(CloudAssemblyBuilder, self, [outdir])
 
     @jsii.member(jsii_name="addArtifact")
-    def add_artifact(self, id: str, *, type: _ArtifactType_9221e05d, dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]]=None, properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c]]=None) -> None:
+    def add_artifact(self, id: str, *, type: _ArtifactType_9221e05d, dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]]=None, properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c, _NestedCloudAssemblyProperties_2d939e98]]=None) -> None:
         """Adds an artifact into the cloud assembly.
 
         :param id: The ID of the artifact.
@@ -447,6 +471,18 @@ class CloudAssemblyBuilder(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experimen
 
         return jsii.invoke(self, "buildAssembly", [options])
 
+    @jsii.member(jsii_name="createNestedAssembly")
+    def create_nested_assembly(self, artifact_id: str, display_name: str) -> "CloudAssemblyBuilder":
+        """Creates a nested cloud assembly.
+
+        :param artifact_id: -
+        :param display_name: -
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "createNestedAssembly", [artifact_id, display_name])
+
     @builtins.property
     @jsii.member(jsii_name="outdir")
     def outdir(self) -> str:
@@ -463,7 +499,7 @@ class CloudFormationStackArtifact(CloudArtifact, metaclass=jsii.JSIIMeta, jsii_t
     stability
     :stability: experimental
     """
-    def __init__(self, assembly: "CloudAssembly", artifact_id: str, *, type: _ArtifactType_9221e05d, dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]]=None, properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c]]=None) -> None:
+    def __init__(self, assembly: "CloudAssembly", artifact_id: str, *, type: _ArtifactType_9221e05d, dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]]=None, properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c, _NestedCloudAssemblyProperties_2d939e98]]=None) -> None:
         """
         :param assembly: -
         :param artifact_id: -
@@ -1212,6 +1248,70 @@ class MissingContext():
         return 'MissingContext(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+class NestedCloudAssemblyArtifact(CloudArtifact, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.cx_api.NestedCloudAssemblyArtifact"):
+    """Asset manifest is a description of a set of assets which need to be built and published.
+
+    stability
+    :stability: experimental
+    """
+    def __init__(self, assembly: "CloudAssembly", name: str, *, type: _ArtifactType_9221e05d, dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]]=None, properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c, _NestedCloudAssemblyProperties_2d939e98]]=None) -> None:
+        """
+        :param assembly: -
+        :param name: -
+        :param type: The type of artifact.
+        :param dependencies: IDs of artifacts that must be deployed before this artifact. Default: - no dependencies.
+        :param environment: The environment into which this artifact is deployed. Default: - no envrionment.
+        :param metadata: Associated metadata. Default: - no metadata.
+        :param properties: The set of properties for this artifact (depends on type). Default: - no properties.
+
+        stability
+        :stability: experimental
+        """
+        artifact = _ArtifactManifest_38498e6d(type=type, dependencies=dependencies, environment=environment, metadata=metadata, properties=properties)
+
+        jsii.create(NestedCloudAssemblyArtifact, self, [assembly, name, artifact])
+
+    @builtins.property
+    @jsii.member(jsii_name="directoryName")
+    def directory_name(self) -> str:
+        """The relative directory name of the asset manifest.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "directoryName")
+
+    @builtins.property
+    @jsii.member(jsii_name="displayName")
+    def display_name(self) -> str:
+        """Display name.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "displayName")
+
+    @builtins.property
+    @jsii.member(jsii_name="fullPath")
+    def full_path(self) -> str:
+        """Full path to the nested assembly directory.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "fullPath")
+
+    @builtins.property
+    @jsii.member(jsii_name="nestedAssembly")
+    def nested_assembly(self) -> "CloudAssembly":
+        """The nested Assembly.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "nestedAssembly")
+
+
 @jsii.data_type(jsii_type="monocdk-experiment.cx_api.RuntimeInfo", jsii_struct_bases=[_RuntimeInfo_847d082a], name_mapping={'libraries': 'libraries'})
 class RuntimeInfo(_RuntimeInfo_847d082a):
     def __init__(self, *, libraries: typing.Mapping[str, str]) -> None:
@@ -1333,7 +1433,7 @@ class TreeCloudArtifact(CloudArtifact, metaclass=jsii.JSIIMeta, jsii_type="monoc
     stability
     :stability: experimental
     """
-    def __init__(self, assembly: "CloudAssembly", name: str, *, type: _ArtifactType_9221e05d, dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]]=None, properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c]]=None) -> None:
+    def __init__(self, assembly: "CloudAssembly", name: str, *, type: _ArtifactType_9221e05d, dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]]=None, properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c, _NestedCloudAssemblyProperties_2d939e98]]=None) -> None:
         """
         :param assembly: -
         :param name: -
@@ -1729,7 +1829,7 @@ class AssetManifestArtifact(CloudArtifact, metaclass=jsii.JSIIMeta, jsii_type="m
     stability
     :stability: experimental
     """
-    def __init__(self, assembly: "CloudAssembly", name: str, *, type: _ArtifactType_9221e05d, dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]]=None, properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c]]=None) -> None:
+    def __init__(self, assembly: "CloudAssembly", name: str, *, type: _ArtifactType_9221e05d, dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List[_MetadataEntry_1c069657]]]=None, properties: typing.Optional[typing.Union[_AwsCloudFormationStackProperties_cbabc075, _AssetManifestProperties_8c80271b, _TreeArtifactProperties_8af66c6c, _NestedCloudAssemblyProperties_2d939e98]]=None) -> None:
         """
         :param assembly: -
         :param name: -
@@ -1784,6 +1884,7 @@ __all__ = [
     "MetadataEntry",
     "MetadataEntryResult",
     "MissingContext",
+    "NestedCloudAssemblyArtifact",
     "RuntimeInfo",
     "SynthesisMessage",
     "SynthesisMessageLevel",
